Header menu logo UnionConfig

SsmConfigStore Module

Generic config store backed by a parameter store. Maps config var names to parameter paths and provides CRUD operations.

Types

Type Description

SsmConfigStore

A config store backed by a parameter store

SsmOperations

Operations for interacting with a parameter store. Consumers provide an implementation (e.g., backed by AWS SSM).

SsmPathMapping

Maps config var names to parameter paths

Functions and values

Function or value Description

applyChanges store changes

Full Usage: applyChanges store changes

Parameters:
Returns: (string * bool * bool) array

Apply a set of changes. Each change is (key, oldValue, newValue). Deletions occur when newValue is empty and oldValue was not. Returns (key, success, wasDelete) for each change.

store : SsmConfigStore
changes : (string * string * string) array
Returns: (string * bool * bool) array

deleteValue store name

Full Usage: deleteValue store name

Parameters:
Returns: bool

Delete a config value. Returns true on success, false on error.

store : SsmConfigStore
name : string
Returns: bool

getValue store name

Full Usage: getValue store name

Parameters:
Returns: string option

Get a single config value

store : SsmConfigStore
name : string
Returns: string option

loadAll store varNames

Full Usage: loadAll store varNames

Parameters:
Returns: Map<string, string>

Load all config values for the given var names. Returns a Map with all names as keys (empty string for missing values).

store : SsmConfigStore
varNames : string array
Returns: Map<string, string>

setValue store name value

Full Usage: setValue store name value

Parameters:
Returns: bool

Set a single config value (auto-determines SecureString from IsSecret)

store : SsmConfigStore
name : string
value : string
Returns: bool

Type something to start searching.