Header menu logo UnionConfig

ConfigRequirement Type

Whether a configuration variable is required for the app to start

Union cases

Union case Description

Optional

Full Usage: Optional

Var can be missing; read returns None

Required

Full Usage: Required

App will fail to start if this var is missing or empty

Instance members

Instance member Description

this.IsOptional

Full Usage: this.IsOptional

Returns: bool
Returns: bool

this.IsRequired

Full Usage: this.IsRequired

Returns: bool
Returns: bool

Type something to start searching.