SsmConfigStore Module
Generic config store backed by a parameter store. Maps config var names to parameter paths and provides CRUD operations.
Types
| Type | Description |
|
A config store backed by a parameter store |
|
|
Operations for interacting with a parameter store. Consumers provide an implementation (e.g., backed by AWS SSM). |
|
|
Maps config var names to parameter paths |
Functions and values
| Function or value |
Description
|
Full Usage:
applyChanges store changes
Parameters:
SsmConfigStore
changes : (string * string * string) array
Returns: (string * bool * bool) array
|
Apply a set of changes. Each change is (key, oldValue, newValue). Deletions occur when newValue is empty and oldValue was not. Returns (key, success, wasDelete) for each change.
|
|
Delete a config value. Returns true on success, false on error.
|
Full Usage:
getValue store name
Parameters:
SsmConfigStore
name : string
Returns: string option
|
|
Full Usage:
loadAll store varNames
Parameters:
SsmConfigStore
varNames : string array
Returns: Map<string, string>
|
Load all config values for the given var names. Returns a Map with all names as keys (empty string for missing values).
|
Full Usage:
setValue store name value
Parameters:
SsmConfigStore
name : string
value : string
Returns: bool
|
Set a single config value (auto-determines SecureString from IsSecret)
|
UnionConfig