ConfigRequirement Type
Whether a configuration variable is required for the app to start
Union cases
| Union case |
Description
|
Full Usage:
Optional
|
Var can be missing; read returns None |
Full Usage:
Required
|
App will fail to start if this var is missing or empty |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsOptional
Returns: bool
|
|
Full Usage:
this.IsRequired
Returns: bool
|
|
UnionConfig