ConfigValue Module
Helpers for extracting typed values from ConfigValue. Use these with a `read` function that returns ConfigValue option: let port = read PORT |> ConfigValue.int let apiKey = read XAI_API_KEY |> ConfigValue.stringOption
Functions and values
| Function or value |
Description
|
|
|
|
|
Full Usage:
custom parser cv
Parameters:
string -> 'T option
cv : ConfigValue option
Returns: 'T
|
Parse custom type from Required config using provided parser
|
Full Usage:
customOption parser cv
Parameters:
string -> 'T option
cv : ConfigValue option
Returns: 'T option
|
Parse custom type from Optional config using provided parser
|
|
|
|
|
|
|
|
|
|
Extract string from Required config (converts any type to string)
|
|
Extract string from Optional config (converts any type to string)
|
UnionConfig